@@ -3,9 +3,21 @@
 # Algo Metropolis-Hastings
 # ------------------------
 
-.MHalgoGen<-function(n.iter=10000, parameters=NULL, data=NULL, likelihood=NULL, n.chains = 4, n.adapt = 100, thin=30, trace=FALSE)
+.MHalgoGen<-function(n.iter=10000, parameters=NULL, data=NULL, likelihood=NULL, 
+n.chains = 4, n.adapt = 100, thin=30, trace=FALSE)
 {
 
+t <- as.character(trace)
+pt <- NULL
+if (t=="TRUE") {pt <- 1;tf <- TRUE}
+if (t=="FALSE") {pt <- 0;tf <- FALSE}
+if (is.null(pt)) {
+  tf <- TRUE
+  pt <- floor((n.adapt+n.iter)/trace)
+}
+
+cpt_trace <- 0
+
 
 res<-as.list(NULL)
 resL<-as.list(NULL)
@@ -82,9 +94,13 @@ for (i in 2:(n.adapt+n.iter+1))
 		varp2[cpt, "Ln L"]<-varp[i, "Ln L"]
 		cpt<-cpt+1
 #	}
-	if (trace) {
-	  cat(paste("Chain ", kk, ": [", i, "] ", as.numeric(varp[i, "Ln L"]), "\n", sep=""))
-	}
+	if (tf) {
+    cpt_trace <- cpt_trace+1
+    if (cpt_trace>=pt) {
+	    cat(paste("Chain ", kk, ": [", i, "] ", as.numeric(varp[i, "Ln L"]), "\n", sep=""))
+      cpt_trace <- 0
+    }
+  }
 }
 
 lp <- as.mcmc(varp2[1:(cpt-1), 1:nbvar])
